uma-ase Web Interface

## Input Details

Select Input file
Charge
Spin Multiplicity
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Optimizer
Force (eV/Å)
Max GeoOpt Iter

Vib Analysis Settings

Temperature (K)
Pressure (Pa)

### Summary

    No structure loaded.

## Calculate

## Results

Select an input file and run a job to see results here.

## Input Details

Select a Folder
No folder selected
MLFF Checkpoint
MLFF Task
Run Type
Single Point GeoOpt Frequencies
Optimizer
Force (eV/Å)
Max Iter

Vib Analysis Settings

Temperature (K)
Pressure (Pa)

### Summary

    No folder selected.

## Calculate

## Results

## Input Details

Input file No file selected
Charge
Spin Multiplicity

### Summary

    No structure loaded.

## Analyze

Select a folder

#### RMSD Report

Reads uma-ase .log files (Formula, RMSD, uma model, optimizer) and generates a bar plot and a table of RMSDs by formula.

#### XYZ Pair Analysis

Matches *.xyz files with their *geoopt-OPT* counterparts and detailed geometry analysis. Python script provided by A. Solé-Daura.